package com.simuwang.manage.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.common.util.DateUtils;
import com.simuwang.base.mapper.daq.CompanyContactInfoMapper;
import com.simuwang.base.mapper.daq.ContactInformationMapper;
import com.simuwang.base.pojo.dos.ContactInformationDO;
import com.simuwang.base.pojo.dto.query.ContactQuery;
import com.simuwang.base.pojo.vo.ContactInformationVO;
import com.simuwang.manage.service.ContactInformationService;
import com.simuwang.shiro.utils.UserUtils;
import com.smppw.common.pojo.ResultVo;
import com.smppw.common.pojo.enums.status.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class ContactInformationServiceImpl implements ContactInformationService {
    @Autowired
    private ContactInformationMapper contactInformationMapper;

    @Autowired
    private CompanyContactInfoMapper companyContactInfoMapper;

    @Override
    public ResultVo saveContactInformation(List<ContactInformationVO> contactInformationVOList) {
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS.getCode());
        for (ContactInformationVO contactInformationVO : contactInformationVOList) {
            contactInformationVO.setUpdateTime(DateUtils.getTime());
            contactInformationVO.setIsvalid(1);
            contactInformationVO.setCreatorId(UserUtils.getLoginUser().getUserId());
            contactInformationVO.setUpdaterId(UserUtils.getLoginUser().getUserId());
            ContactInformationDO contactInformationDO = BeanUtil.copyProperties(contactInformationVO, ContactInformationDO.class);
            ContactInformationDO oldContactInformationDO = contactInformationMapper.getContactInformation(contactInformationDO);
            if (oldContactInformationDO != null && contactInformationVO.getId() == null) {
                vo.setData(false);
                vo.setMsg("联系人信息已经存在，无需新增");
                return vo;
            }
            if (oldContactInformationDO == null) {
                contactInformationDO.setCreateTime(new Date());
                contactInformationMapper.insert(contactInformationDO);
            } else {
                contactInformationDO.setId(oldContactInformationDO.getId());
                contactInformationMapper.updateById(contactInformationDO);
            }
        }
        return vo;
    }

    @Override
    public MybatisPage<ContactInformationVO> selectContactInformationList(ContactQuery contactQuery) {
        List<ContactInformationDO> contactInformationDOList = contactInformationMapper.selectContactInformationList(contactQuery);
        long total = contactInformationMapper.countContactInfo(contactQuery);
        List<ContactInformationVO> dataList = contactInformationDOList.stream().map(ContactInformationDO::toVO).collect(Collectors.toList());
        return MybatisPage.of(total,dataList);
    }

    @Override
    public ResultVo deleteById(Integer id) {
        ResultVo vo = new ResultVo(ResultCode.DELETE_SUCCESS.getCode());
        Integer userId = UserUtils.getLoginUser().getUserId();
        //判断联系人是否绑定对接信息，如果有不能删除
        int contactCount = companyContactInfoMapper.selectCountByContactId(id);
        if(contactCount > 0) {
            vo.setCode(ResultCode.DELETE_FAILED.getCode());
            vo.setData(false);
            vo.setMsg("联系人有绑定对接信息，不能删除");
            return vo;
        }
        contactInformationMapper.deleteContactInformationById(id,userId);
        vo.setData(true);
        return vo;
    }
}
